Documentation
¶
Overview ¶
Package smap is a thread-safe map with generic any key and any value.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Smap ¶
type Smap[K comparable, V any] struct{ sync.Map }
Smap is a thread safe map with generic comparable key and any value.
func (*Smap[K, V]) Get ¶
Get returns the value stored in the map for a key, or default V type value if no value is present by key. The ok result indicates whether value was found in the map.
Click to show internal directories.
Click to hide internal directories.